@@ -1,6 +1,6 @@
 # fourFn.py
 #
-# Demonstration of the parsing module, implementing a simple 4-function expression parser,
+# Demonstration of the pyparsing module, implementing a simple 4-function expression parser,
 # with support for scientific notation, and symbols for e and pi.
 # Extended to add exponentiation and simple built-in functions.
 # Extended test cases, simplified pushFirst method.
@@ -138,6 +138,7 @@ if __name__ == "__main__":
     test( "E^PI", math.e**math.pi )
     test( "2^3^2", 2**3**2 )
     test( "2^3+2", 2**3+2 )
+    test( "2^3+5", 2**3+5 )
     test( "2^9", 2**9 )
     test( "sgn(-2)", -1 )
     test( "sgn(0)", 0 )
